using System;
using System.Data;
using System.Data.SqlClient;
using System.Configuration;
using System.Text;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

/// <summary>
/// Summary description for EmpInfo
/// </summary>
public class EmpInfo
{
    private string _connectionString = string.Empty;
    private string _sortColumns = string.Empty;

	public EmpInfo()
	{
        _connectionString = GetConnection();
	}

    public string SortColumns {
        get { return _sortColumns; }
        set { _sortColumns = value; }
    }

    public DataSet GetFullDataSet() {
        return GetDataSet(AssembleSelectSql());
    }

    public DataSet GetPagedDataSet(int startRow, int pageSize, string sortColumns) {
        if (sortColumns.Length > 0)
            _sortColumns = sortColumns;
        // If you want to set the default sort order in the data class, 
        // here's one place you could do it.
        //else
        //    _sortColumns = "LastName, FirstName";
        return GetDataSet(AssemblePagedSelectSql(startRow, pageSize));
    }

    public int GetRowCount() {
        using (SqlConnection conn = new SqlConnection(_connectionString)) {
            conn.Open();
            using (SqlCommand cmd = new SqlCommand("SELECT COUNT(*) FROM HumanResources.vEmployee", conn)) {
                return (int)cmd.ExecuteScalar();
            }
        }
    }

    public DataSet GetDataSet(string sql) {
        DataSet ds = new DataSet();

        using (SqlConnection conn = new SqlConnection(_connectionString)) {
            conn.Open();
            using (SqlDataAdapter da = new SqlDataAdapter(sql, conn)) {
                da.Fill(ds);
            }
        }

        return ds;
    }

    private string AssembleSelectSql() {
        StringBuilder sql = new StringBuilder();

        sql.Append("SELECT EmployeeId, FirstName, MiddleName, LastName, JobTitle");
        sql.Append(" FROM HumanResources.vEmployee");

        return sql.ToString();
    }

    private string AssemblePagedSelectSql(int startRow, int pageSize) {
        StringBuilder sql = new StringBuilder();

        // The "core" select statement is: "SELECT EmployeeId, FirstName, MiddleName, LastName, JobTitle FROM HumanResources.vEmployee"
        // The rest of this code inserts a RowNumber column into the result set and wraps the entire select with paging conditions.
        sql.Append("SELECT * FROM (");
        sql.Append("SELECT EmployeeId, FirstName, MiddleName, LastName, JobTitle");
        sql.AppendFormat(", ROW_NUMBER() OVER (ORDER BY {0}) AS ResultSetRowNumber", _sortColumns);
        sql.Append(" FROM HumanResources.vEmployee) AS PagedResults");
        sql.AppendFormat(" WHERE ResultSetRowNumber > {0} AND ResultSetRowNumber <= {1}", startRow.ToString(), (startRow + pageSize).ToString());

        return sql.ToString();
    }

    private string GetConnection() {
        return System.Web.Configuration.WebConfigurationManager.AppSettings["AdventureWorksConnectionString"];
    }
}
